package com.sct.pipeline.uportal.channels.deployTest;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.ServletContext;
import javax.servlet.ServletConfig;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jasig.portal.IWorkerRequestProcessor;
import org.jasig.portal.PortalControlStructures;
import org.jasig.portal.PortalSessionManager;
import org.jasig.portal.car.CarResources;
import java.io.File;
import java.io.InputStream;
import java.io.FileOutputStream;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
   Simple class to pull an image out of a CAR and place it in the uPortal
   web visible area so that it is directly accessible to browsers.
   @author Mark Boyd <mboyd@sct.com>
 */
public class Extractor
    extends DefaultHandler
{
    public final static String RCS_ID = "@(#) $Header: /src/luminis/src/uPortal/source/org/jasig/portal/car/CarResourceWorker.java,v 1.5 2003/05/30 17:46:46 jpurser Exp $";

    private String mPathInCar = null;
    private String mPathToMedia = null;
    
    private String getMediaPath()
    throws Exception
    {
	if ( mPathToMedia == null )
	{
	    PortalSessionManager servlet = PortalSessionManager.getInstance();
	    ServletConfig cfg = servlet.getServletConfig();
	    ServletContext ctx = cfg.getServletContext();
	    mPathToMedia = ctx.getRealPath( "/media" );
	}
	
	if ( mPathToMedia == null )
	    throw new Exception( "Unable to access /media directory." );

	return mPathToMedia;
    }

    private boolean isWebVisibleImageAvailable()
    throws Exception
    {
	String mediaPath = getMediaPath();
	File image = new File( mediaPath + "/youveGotIt.jpg" );
	return image.exists();
    }
	
    public void startElement( String nsURI,
                              String localName,
                              String qName,
                              Attributes atts )
        throws SAXException
    {
        if ( qName.equals( "file" ) )
	    mPathInCar = atts.getValue( "pathInCar" );
    }

    public void endDocument()
        throws SAXException
    {
	try
	{
	    if ( mPathInCar == null )
		return;
	    if ( ! isWebVisibleImageAvailable() )
	    {
		ClassLoader cl = CarResources.getInstance().getClassLoader();
		InputStream in = cl.getResourceAsStream( mPathInCar );
		FileOutputStream file = null;
		file = new FileOutputStream( getMediaPath() +
					     "/youveGotIt.jpg" );
		byte[] bytes = new byte[4096];
		int bytesRead = in.read( bytes, 0, 4096 );
		
		while ( bytesRead > 0 )
		{
		    file.write( bytes, 0, bytesRead );
		    bytesRead = in.read( bytes, 0, 4096 );
		}
		file.flush();
		file.close();
	    }
	}
	catch( Exception e )
	{
	    throw new SAXException( "Problem occurred extracting image file " +
				    "from CAR.", e );
	}
    }
}
