package com.sct.pipeline.uportal.channels.deployTest;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import java.io.PrintWriter;
import java.util.Hashtable;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jasig.portal.IWorkerRequestProcessor;
import org.jasig.portal.PortalControlStructures;
import org.jasig.portal.PortalException;


/**
   Simple worker class to serve up a page confirming proper deployment of a
   worker, service, and extension block in a channel archive.
   @author Mark Boyd <mboyd@sct.com>
 */
public class HelloWorker
    implements IWorkerRequestProcessor
{

    public final static String RCS_ID = "@(#) $Header: /src/luminis/src/uPortal/source/org/jasig/portal/car/CarResourceWorker.java,v 1.5 2003/05/30 17:46:46 jpurser Exp $";

    private static HitsService cHitsService = null;
    
    private HitsService getHitsService() throws PortalException
    {
	if ( cHitsService == null )
	{
	    try
	    {
		Hashtable env = new Hashtable(2);
		env.put( Context.INITIAL_CONTEXT_FACTORY,
			 "org.jasig.portal.jndi.PortalInitialContextFactory" );
		Context ctx = new InitialContext( env );
		cHitsService = (HitsService) ctx
		    .lookup( "services/hitsService" );
	    }
	    catch( NamingException ne )
	    {
		throw new PortalException( "Unable to aquire HitsService.",
					   ne );
	    }
	}
	return cHitsService;
    }

    /** 
     Provides web access to channel resources stored in the channel archive
     files. housing the channel if the channel was installed in the uPortal
     using a CAR. 

     @author <a href="mailto:mboyd@campuspipeline.com">Mark Boyd</a>
    */
    public void processWorkerDispatch( PortalControlStructures pcs )
        throws PortalException
    {
	try
	{
	    HttpServletRequest req=pcs.getHttpServletRequest();
	    HttpServletResponse res=pcs.getHttpServletResponse();

	    // make sure our response doesn't get cached.
	    res.setHeader ( "Cache-Control", "no-cache" );
	    res.setHeader ( "Pragma", "no-cache" );
	    res.setHeader ( "Expires", "Wed, 01 Jan 1970 00:00:00 GMT" );
	
	    res.setContentType("text/html");
	    PrintWriter out = res.getWriter();

	    out.println( "<html><body>" );
	    out.println( "<br><table cellpadding='3' width='100%'><tr><td>" );
	    out.println( "<tr><td align='CENTER'><a href='worker.com_sct_" +
			 "pipeline_uportal_channels_deployTest_" +
			 "HelloWorker.uP'><img border='0' " +
			 "src='media/youveGotIt.jpg'/></a></td></tr>" );
	    out.println( "<tr><td align='CENTER'><h1>The Hello Worker" +
			 "</h1><i>This was request number: " +
			 getHitsService().getHits()+ "</i></td></tr>" );
	    out.println( "<tr><td>If you see this page then you have " +
			 "successfully used a Channel ARchive deployment " +
			 "desriptor to " +
			 "deploy the Hello Worker. </td></tr>" );
	    out.println( "<tr><td>Additionally, if the " +
			 "request number is incrementing you have also " +
			 "successfully installed a service which " +
			 "is accessed by the portal's JNDI context and " +
			 "keeps track of how many times the Hello worker " +
			 "has been accessed since bouncing the web server." +
			 "</td></tr>" );
	    out.println( "<tr><td>Finally, if you see a non-broken image " +
			 "that says, \"You've Got it!\" then you have " +
			 "successfully used a CAR deployment descriptor " +
			 "extension block which instantiates a class to " +
			 "pull this image out of the CAR and places it in " +
			 "the <uPortalWebAppRoot>/media " +
			 "directory so that it is web visible and does not " +
			 "require being served up out of the CAR. Clicking " +
			 "on the image will refresh this page " +
			 "causing the request number to increase.</td></tr>" );
	    out.println( "</table></body></html>" );
	    out.flush();
	    out.close();
        }
        catch( Exception ex )
        {
	    //StringWriter sw = new StringWriter();
	    //PrintWriter pw = new Print
            throw new PortalException( "Problem in HelloWorker. " +
				       ( ex.getMessage() != null ?
					 "Details: " + ex.getMessage() : "" ),
				       ex );
        }
    }
}
